# -*- coding: utf-8 -*-
'''
Task Poach - Strives to be a Task Coach compatible TODO app.
Copyright (C) 2012 computerinfo21@gmail.com>

Task Poach is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Task Poach is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''
"""
Module implementing HelpWindow.
"""

from PyQt4.QtGui import QMainWindow
from PyQt4.QtCore import pyqtSignature

from Ui_help import Ui_HelpWindow
from PyQt4.QtCore import QUrl
from os import path
from PyQt4 import QtWebKit

class HelpWindow(QMainWindow, Ui_HelpWindow):
    """
    Class documentation goes here.
    """
    def __init__(self, parent = None):
        """
        Constructor
        """
        QMainWindow.__init__(self, parent)
        self.setupUi(self)
        helpPath = "./help/help.html"
        if (not path.exists(helpPath)):
            helpPath = "/opt/taskpoach/help/help.html"
        self.qwebview.load(QUrl.fromLocalFile(path.abspath(helpPath)))
        #print QUrl.fromLocalFile(path.abspath("./help/help.html"))
